pub struct Attached { /* private fields */ }Expand description
A container that attaches elements to the top, bottom, left, or right of an inner element.
Uses absolute positioning and measures the attached element’s size to offset it correctly relative to the inner content.
Example
fn app() -> impl IntoElement {
let mut open = use_state(|| false);
Attached::new(
Button::new()
.on_press(move |_| open.toggle())
.child("Toggle"),
)
.bottom()
.maybe_child(open().then(|| label().text("Attached below!")))
}Implementations